#!/usr/bin/env python
# mintMenu System Management plugin

import gtk
import gtk.glade
import sys
import os
import gobject
import gconf
import gnomevfs
import string
import gettext

from easyfiles import *
from easybuttons import *
from execute import *
from easygconf import *

_ = gettext.gettext

class pluginclass:
	def __init__(self, mintMenuWin, toggleButton):

		self.mintMenuWin = mintMenuWin
		gtk.glade.textdomain( "mintMenu" )
		gtk.glade.bindtextdomain( "mintMenu", self.mintMenuWin.getLocalePath() )
		self.toggleButton = toggleButton

		# The Glade file for the plugin
		self.gladefile = os.path.join(os.path.dirname(__file__), "system_management.glade")

		# Read GLADE file
		self.wTree = gtk.glade.XML(self.gladefile, "window1")

		# These properties are NECESSARY to maintain consistency
		# throughout mintMenu

		# Set 'window' property for the plugin (Must be the root widget)
		self.window = self.wTree.get_widget("window1")
		#dic = {"on_window1_destroy" : gtk.main_quit}
		#self.wTree.signal_autoconnect(dic)

		# Set 'heading' property for plugin
		self.heading = _("System")

		# This should be the first item added to the window in glade
		self.content_holder = self.wTree.get_widget("vbox1")

		# Items to get custom colors
		self.itemstocolor = [self.wTree.get_widget("vbox1")]

		# Gconf stuff
		self.gconf = EasyGConf( "/apps/mintMenu/plugins/system-management/" )

		self.width = self.gconf.get( "int", "width", 200)
		self.height = self.gconf.get( "int", "height", 180)
		self.installsoftware = self.gconf.get( "string", "install_software_cmd", "/usr/lib/linuxmint/mintInstall/mintInstall.py").split()
		self.packagemanager = self.gconf.get( "string", "package_manager_cmd", "gksu /usr/sbin/synaptic").split()
		self.controlcenter = self.gconf.get( "string", "control_center_cmd","gnome-control-center").split()
		self.terminal = self.gconf.get( "string", "terminal_cmd","gnome-terminal").split()
		self.quit_session = self.gconf.get( "string", "quit_cmd", "gnome-session-save --kill").split()
		self.hideseparator = self.gconf.get( "bool", "hide_separator", False)

		# Allow plugin to be minimized to the left plugin pane
		self.sticky = self.gconf.get( "bool", "sticky",False)
		self.minimized = self.gconf.get( "bool", "minimized", False )

		# Plugin icon
		self.icon = self.gconf.get( "string", "icon", "preferences-system")

	def SetHidden( self, state ):
		if state == True:
			self.gconf.set( "bool", "minimized", True )
		else:
			self.gconf.set( "bool", "minimized", False )


	def ButtonClicked(self, widget, Exec):
		self.mintMenuWin.hide()
		Execute( None, Exec )

	def do_setup_window(self):
		self.wTree.get_widget("install_software").connect( "clicked", self.ButtonClicked, self.installsoftware )
		self.wTree.get_widget("package_manager").connect( "clicked", self.ButtonClicked, self.packagemanager )
		self.wTree.get_widget("control_center").connect( "clicked", self.ButtonClicked, self.controlcenter )
		self.wTree.get_widget("terminal").connect( "clicked", self.ButtonClicked, self.terminal )
		self.wTree.get_widget("quit_session").connect( "clicked", self.ButtonClicked, self.quit_session )

	def do_plugin(self):
		self.do_setup_window()






#---------------------------------------------------------------------------------------#
# mintMenuconfig Section Below
#---------------------------------------------------------------------------------------#
# This is the Config Class it must be called "cfgpluginclass'
class cfgpluginclass:
	def __init__(self):
		# The Gladefile for the plugins mintMenuconfig Tab
		self.gladefile = os.path.join(os.path.dirname(__file__), "system_management.glade")
		# Read GLADE file
		self.wTree = gtk.glade.XML(self.gladefile,"config")
		# Set 'window' property for the plugin (Must be the root widget)
		self.window = self.wTree.get_widget("config")
		# Set Heading, this will be used for the tab label in mintMenuconfig
		self.heading = "System"
		# Content Place Holder must be eventbox1
		self.content_holder = self.wTree.get_widget("eventbox2")
		# GConf Stuff - This just makes sure a gconf path is there.
		self.gconf_dir = '/apps/mintMenu/plugins/system-management'
		self.client = gconf.client_get_default()
		self.client.add_dir('/apps/mintMenu/plugins/system-management', gconf.CLIENT_PRELOAD_NONE)
		# Setup the Functions of the Glade files spin controls or entry boxes for Value Changes
		# Tip: For spinbutton controls use the "_value_changed" event not the "_changed" event.
		dic = { "on_window1_destroy" : gtk.main_quit,
				"on_InstCmdEntry_changed" : self.instchange,
				"on_ContCmdEntry_changed" : self.contchange,
				"on_PackCmdEntry_changed" : self.packchange,
				"on_QuitCmdEntry_changed" : self.quitchange,
				"on_HideSepChkBtn_toggled" : self.hidesep,
				"on_SysFontSizeSpin_changed" : self.sysfontspin,
				"on_SysIconSizeSpin_changed" : self.sysiconspin,
				"on_SysHSpin_changed" : self.sysh,
				"on_SysWSpin_changed" : self.sysw,
				"on_SysIconEntry_changed" : self.sysiconchange,
				"on_StickyChkBtn_toggled" : self.syssticky}
		self.wTree.signal_autoconnect(dic)
		# Read Values from Gconf and Set Default Values if they don't exist.
		self.wTree.get_widget("InstCmdEntry").set_text(self.gconf.get( "string","install_software_cmd", "/usr/lib/linuxmint/mintInstall/mintInstall.py"))
		self.wTree.get_widget("ContCmdEntry").set_text(self.gconf.get( "string","control_center_cmd","gnome-control-center"))
		self.wTree.get_widget("PackCmdEntry").set_text(self.gconf.get( "string","package_manager_cmd","gksu /usr/sbin/synaptic"))
		self.wTree.get_widget("QuitCmdEntry").set_text(self.gconf.get( "string","quit_cmd", "gnome-session-save --kill"))
		self.wTree.get_widget("HideSepChkBtn").set_active(self.gconf.get( 'bool', 'hide_separator',False))
		self.wTree.get_widget("SysFontSizeSpin").set_value(int(self.gconf.get( 'int','font_size',9)))
		self.wTree.get_widget("SysIconSizeSpin").set_value(int(self.gconf.get( 'int','icon_size',2)))
		self.wTree.get_widget("SysHSpin").set_value(int(self.gconf.get( 'int','height',280)))
		self.wTree.get_widget("SysWSpin").set_value(int(self.gconf.get( 'int','width',200)))
		self.wTree.get_widget("SysIconEntry").set_text(self.gconf.get( 'string','icon','computer.png'))
		self.wTree.get_widget("StickyChkBtn").set_active(self.gconf.get( 'bool','sticky',False))

	# Functions for Changing Values when items checked or altered Section
	def instchange(self, widget, **kargs):
		self.client.set_string('install_software_cmd',self.wTree.get_widget("InstCmdEntry").get_text())

	def contchange(self, widget, **kargs):
		self.client.set_string('control_center_cmd',self.wTree.get_widget("ContCmdEntry").get_text())

	def packchange(self, widget, **kargs):
		self.client.set_string('package_manager_cmd',self.wTree.get_widget("PackCmdEntry").get_text())

	def quitchange(self, widget, **kargs):
		self.client.set_string('quit_cmd',self.wTree.get_widget("QuitCmdEntry").get_text())

	def sysfontspin(self, widget, **kargs):
		self.client.set_int('font_size',int(self.wTree.get_widget("SysFontSizeSpin").get_value()))

	def sysiconspin(self, widget, **kargs):
		self.client.set_int('icon_size',int(self.wTree.get_widget("SysIconSizeSpin").get_value()))

	def sysh(self, widget, **kargs):
		self.client.set_int('height',int(self.wTree.get_widget("SysHSpin").get_value()))

	def sysw(self, widget, **kargs):
		self.client.set_int('width',int(self.wTree.get_widget("SysWSpin").get_value()))

	def hidesep(self, widget, **kargs):
		if self.wTree.get_widget("HideSepChkBtn").get_active() == True:
			self.client.set_bool('hide_separator',True)
		else:
			self.client.set_bool('hide_separator',False)

	def sysiconchange(self, widget, **kargs):
		self.icon=self.wTree.get_widget("SysIconEntry").get_text()
		self.client.set_string('icon',self.wTree.get_widget('SysIconEntry').get_text())

	def syssticky(self, widget, **kargs):
		if self.wTree.get_widget("StickyChkBtn").get_active() == True:
			self.client.set_bool('sticky',True)
		else:
			self.client.set_bool('sticky',False)

